# swagger-client
A full API to use your BTCPay Server

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen
For more information, please visit [https://btcpayserver.org](https://btcpayserver.org)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: API_Key
configuration = swagger_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'# Configure HTTP basic authorization: Basic
configuration = swagger_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = swagger_client.APIKeysApi(swagger_client.ApiClient(configuration))
apikey = 'apikey_example' # str | The API Key to revoke

try:
    # Revoke an API Key
    api_instance.api_v1_api_keys_apikey_delete(apikey)
except ApiException as e:
    print("Exception when calling APIKeysApi->api_v1_api_keys_apikey_delete: %s\n" % e)

# Configure API key authorization: API_Key
configuration = swagger_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.APIKeysApi(swagger_client.ApiClient(configuration))

try:
    # Revoke the current API Key
    api_response = api_instance.api_v1_api_keys_current_delete()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APIKeysApi->api_v1_api_keys_current_delete: %s\n" % e)

# Configure API key authorization: API_Key
configuration = swagger_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.APIKeysApi(swagger_client.ApiClient(configuration))

try:
    # Get the current API Key information
    api_response = api_instance.api_v1_api_keys_current_get()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APIKeysApi->api_v1_api_keys_current_get: %s\n" % e)

# Configure API key authorization: API_Key
configuration = swagger_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'# Configure HTTP basic authorization: Basic
configuration = swagger_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = swagger_client.APIKeysApi(swagger_client.ApiClient(configuration))
body = swagger_client.V1ApikeysBody() # V1ApikeysBody |  (optional)

try:
    # Create a new API Key
    api_response = api_instance.api_v1_api_keys_post(body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling APIKeysApi->api_v1_api_keys_post: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APIKeysApi* | [**api_v1_api_keys_apikey_delete**](docs/APIKeysApi.md#api_v1_api_keys_apikey_delete) | **DELETE** /api/v1/api-keys/{apikey} | Revoke an API Key
*APIKeysApi* | [**api_v1_api_keys_current_delete**](docs/APIKeysApi.md#api_v1_api_keys_current_delete) | **DELETE** /api/v1/api-keys/current | Revoke the current API Key
*APIKeysApi* | [**api_v1_api_keys_current_get**](docs/APIKeysApi.md#api_v1_api_keys_current_get) | **GET** /api/v1/api-keys/current | Get the current API Key information
*APIKeysApi* | [**api_v1_api_keys_post**](docs/APIKeysApi.md#api_v1_api_keys_post) | **POST** /api/v1/api-keys | Create a new API Key
*AppsApi* | [**apps_create_point_of_sale_app**](docs/AppsApi.md#apps_create_point_of_sale_app) | **POST** /api/v1/stores/{storeId}/apps/pos | Create a new Point of Sale app
*AppsApi* | [**apps_delete_point_of_sale_app**](docs/AppsApi.md#apps_delete_point_of_sale_app) | **DELETE** /api/v1/apps/{appId} | Delete app
*AppsApi* | [**apps_get_point_of_sale_app**](docs/AppsApi.md#apps_get_point_of_sale_app) | **GET** /api/v1/apps/{appId} | Get basic app data
*AuthorizationApi* | [**api_keys_authorize_get**](docs/AuthorizationApi.md#api_keys_authorize_get) | **GET** /api-keys/authorize | Authorize User
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_addresses_payment_method_get) | **GET** /api/v1/stores/{storeId}/custodian-accounts/{accountId}/addresses/{paymentMethod} | Get a deposit address for custodian
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_delete**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_delete) | **DELETE** /api/v1/stores/{storeId}/custodian-accounts/{accountId} | Delete store custodian account
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_get**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_get) | **GET** /api/v1/stores/{storeId}/custodian-accounts/{accountId} | Get store custodian account
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_put**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_put) | **PUT** /api/v1/stores/{storeId}/custodian-accounts/{accountId} | Update custodial account
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_trades_market_post) | **POST** /api/v1/stores/{storeId}/custodian-accounts/{accountId}/trades/market | Trade one asset for another
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_trades_quote_get) | **GET** /api/v1/stores/{storeId}/custodian-accounts/{accountId}/trades/quote | Get quote for trading one asset for another
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_post) | **POST** /api/v1/stores/{storeId}/custodian-accounts/{accountId}/withdrawals | Withdraw to store wallet
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_account_id_withdrawals_withdrawal_id_post) | **POST** /api/v1/stores/{storeId}/custodian-accounts/{accountId}/withdrawals/{withdrawalId} | Get withdrawal info
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_get**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_get) | **GET** /api/v1/stores/{storeId}/custodian-accounts | List store custodian accounts
*CustodiansApi* | [**api_v1_stores_store_id_custodian_accounts_post**](docs/CustodiansApi.md#api_v1_stores_store_id_custodian_accounts_post) | **POST** /api/v1/stores/{storeId}/custodian-accounts | Add a custodial account to a store.
*CustodiansApi* | [**custodians_get_supported_custodians**](docs/CustodiansApi.md#custodians_get_supported_custodians) | **GET** /api/v1/custodians | List supported custodians
*HealthApi* | [**health_get_health**](docs/HealthApi.md#health_get_health) | **GET** /api/v1/health | Get health status
*InvoicesApi* | [**invoices_activate_payment_method**](docs/InvoicesApi.md#invoices_activate_payment_method) | **POST** /api/v1/stores/{storeId}/invoices/{invoiceId}/payment-methods/{paymentMethod}/activate | Activate Payment Method
*InvoicesApi* | [**invoices_archive_invoice**](docs/InvoicesApi.md#invoices_archive_invoice) | **DELETE** /api/v1/stores/{storeId}/invoices/{invoiceId} | Archive invoice
*InvoicesApi* | [**invoices_create_invoice**](docs/InvoicesApi.md#invoices_create_invoice) | **POST** /api/v1/stores/{storeId}/invoices | Create a new invoice
*InvoicesApi* | [**invoices_get_invoice**](docs/InvoicesApi.md#invoices_get_invoice) | **GET** /api/v1/stores/{storeId}/invoices/{invoiceId} | Get invoice
*InvoicesApi* | [**invoices_get_invoice_payment_methods**](docs/InvoicesApi.md#invoices_get_invoice_payment_methods) | **GET** /api/v1/stores/{storeId}/invoices/{invoiceId}/payment-methods | Get invoice payment methods
*InvoicesApi* | [**invoices_get_invoices**](docs/InvoicesApi.md#invoices_get_invoices) | **GET** /api/v1/stores/{storeId}/invoices | Get invoices
*InvoicesApi* | [**invoices_mark_invoice_status**](docs/InvoicesApi.md#invoices_mark_invoice_status) | **POST** /api/v1/stores/{storeId}/invoices/{invoiceId}/status | Mark invoice status
*InvoicesApi* | [**invoices_unarchive_invoice**](docs/InvoicesApi.md#invoices_unarchive_invoice) | **POST** /api/v1/stores/{storeId}/invoices/{invoiceId}/unarchive | Unarchive invoice
*InvoicesApi* | [**invoices_update_invoice**](docs/InvoicesApi.md#invoices_update_invoice) | **PUT** /api/v1/stores/{storeId}/invoices/{invoiceId} | Update invoice
*LightningInternalNodeApi* | [**internal_lightning_node_api_connect_to_node**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_connect_to_node) | **POST** /api/v1/server/lightning/{cryptoCode}/connect | Connect to lightning node
*LightningInternalNodeApi* | [**internal_lightning_node_api_create_invoice**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_create_invoice) | **POST** /api/v1/server/lightning/{cryptoCode}/invoices | Create lightning invoice
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_balance**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_balance) | **GET** /api/v1/server/lightning/{cryptoCode}/balance | Get node balance
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_channels**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_channels) | **GET** /api/v1/server/lightning/{cryptoCode}/channels | Get channels
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_deposit_address**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_deposit_address) | **POST** /api/v1/server/lightning/{cryptoCode}/address | Get deposit address
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_info**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_info) | **GET** /api/v1/server/lightning/{cryptoCode}/info | Get node information
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_invoice**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_invoice) | **GET** /api/v1/server/lightning/{cryptoCode}/invoices/{id} | Get invoice
*LightningInternalNodeApi* | [**internal_lightning_node_api_get_payment**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_get_payment) | **GET** /api/v1/server/lightning/{cryptoCode}/payments/{paymentHash} | Get payment
*LightningInternalNodeApi* | [**internal_lightning_node_api_open_channel**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_open_channel) | **POST** /api/v1/server/lightning/{cryptoCode}/channels | Open channel
*LightningInternalNodeApi* | [**internal_lightning_node_api_pay_invoice**](docs/LightningInternalNodeApi.md#internal_lightning_node_api_pay_invoice) | **POST** /api/v1/server/lightning/{cryptoCode}/invoices/pay | Pay Lightning Invoice
*LightningStoreApi* | [**store_lightning_node_api_connect_to_node**](docs/LightningStoreApi.md#store_lightning_node_api_connect_to_node) | **POST** /api/v1/stores/{storeId}/lightning/{cryptoCode}/connect | Connect to lightning node
*LightningStoreApi* | [**store_lightning_node_api_create_invoice**](docs/LightningStoreApi.md#store_lightning_node_api_create_invoice) | **POST** /api/v1/stores/{storeId}/lightning/{cryptoCode}/invoices | Create lightning invoice
*LightningStoreApi* | [**store_lightning_node_api_get_balance**](docs/LightningStoreApi.md#store_lightning_node_api_get_balance) | **GET** /api/v1/stores/{storeId}/lightning/{cryptoCode}/balance | Get node balance
*LightningStoreApi* | [**store_lightning_node_api_get_channels**](docs/LightningStoreApi.md#store_lightning_node_api_get_channels) | **GET** /api/v1/stores/{storeId}/lightning/{cryptoCode}/channels | Get channels
*LightningStoreApi* | [**store_lightning_node_api_get_deposit_address**](docs/LightningStoreApi.md#store_lightning_node_api_get_deposit_address) | **POST** /api/v1/stores/{storeId}/lightning/{cryptoCode}/address | Get deposit address
*LightningStoreApi* | [**store_lightning_node_api_get_info**](docs/LightningStoreApi.md#store_lightning_node_api_get_info) | **GET** /api/v1/stores/{storeId}/lightning/{cryptoCode}/info | Get node information
*LightningStoreApi* | [**store_lightning_node_api_get_invoice**](docs/LightningStoreApi.md#store_lightning_node_api_get_invoice) | **GET** /api/v1/stores/{storeId}/lightning/{cryptoCode}/invoices/{id} | Get invoice
*LightningStoreApi* | [**store_lightning_node_api_get_payment**](docs/LightningStoreApi.md#store_lightning_node_api_get_payment) | **GET** /api/v1/stores/{storeId}/lightning/{cryptoCode}/payments/{paymentHash} | Get payment
*LightningStoreApi* | [**store_lightning_node_api_open_channel**](docs/LightningStoreApi.md#store_lightning_node_api_open_channel) | **POST** /api/v1/stores/{storeId}/lightning/{cryptoCode}/channels | Open channel
*LightningStoreApi* | [**store_lightning_node_api_pay_invoice**](docs/LightningStoreApi.md#store_lightning_node_api_pay_invoice) | **POST** /api/v1/stores/{storeId}/lightning/{cryptoCode}/invoices/pay | Pay Lightning Invoice
*MiscelleneousApi* | [**i_invoice_id_get**](docs/MiscelleneousApi.md#i_invoice_id_get) | **GET** /i/{invoiceId} | Invoice checkout
*MiscelleneousApi* | [**lang_codes**](docs/MiscelleneousApi.md#lang_codes) | **GET** /misc/lang | Language codes
*MiscelleneousApi* | [**permissions_metadata**](docs/MiscelleneousApi.md#permissions_metadata) | **GET** /misc/permissions | Permissions metadata
*NotificationsCurrentUserApi* | [**notifications_delete_notification**](docs/NotificationsCurrentUserApi.md#notifications_delete_notification) | **DELETE** /api/v1/users/me/notifications/{id} | Remove Notification
*NotificationsCurrentUserApi* | [**notifications_get_notification**](docs/NotificationsCurrentUserApi.md#notifications_get_notification) | **GET** /api/v1/users/me/notifications/{id} | Get notification
*NotificationsCurrentUserApi* | [**notifications_get_notifications**](docs/NotificationsCurrentUserApi.md#notifications_get_notifications) | **GET** /api/v1/users/me/notifications | Get notifications
*NotificationsCurrentUserApi* | [**notifications_update_notification**](docs/NotificationsCurrentUserApi.md#notifications_update_notification) | **PUT** /api/v1/users/me/notifications/{id} | Update notification
*PaymentRequestsApi* | [**payment_requests_archive_payment_request**](docs/PaymentRequestsApi.md#payment_requests_archive_payment_request) | **DELETE** /api/v1/stores/{storeId}/payment-requests/{paymentRequestId} | Archive payment request
*PaymentRequestsApi* | [**payment_requests_create_payment_request**](docs/PaymentRequestsApi.md#payment_requests_create_payment_request) | **POST** /api/v1/stores/{storeId}/payment-requests | Create a new payment request
*PaymentRequestsApi* | [**payment_requests_get_payment_request**](docs/PaymentRequestsApi.md#payment_requests_get_payment_request) | **GET** /api/v1/stores/{storeId}/payment-requests/{paymentRequestId} | Get payment request
*PaymentRequestsApi* | [**payment_requests_get_payment_requests**](docs/PaymentRequestsApi.md#payment_requests_get_payment_requests) | **GET** /api/v1/stores/{storeId}/payment-requests | Get payment requests
*PaymentRequestsApi* | [**payment_requests_update_payment_request**](docs/PaymentRequestsApi.md#payment_requests_update_payment_request) | **PUT** /api/v1/stores/{storeId}/payment-requests/{paymentRequestId} | Update payment request
*PayoutProcessorsApi* | [**payout_processors_get_payout_processors**](docs/PayoutProcessorsApi.md#payout_processors_get_payout_processors) | **GET** /api/v1/payout-processors | Get payout processors
*PullPaymentsManagementApi* | [**pull_payments_archive_pull_payment**](docs/PullPaymentsManagementApi.md#pull_payments_archive_pull_payment) | **DELETE** /api/v1/stores/{storeId}/pull-payments/{pullPaymentId} | Archive a pull payment
*PullPaymentsManagementApi* | [**pull_payments_create_pull_payment**](docs/PullPaymentsManagementApi.md#pull_payments_create_pull_payment) | **POST** /api/v1/stores/{storeId}/pull-payments | Create a new pull payment
*PullPaymentsManagementApi* | [**pull_payments_get_pull_payments**](docs/PullPaymentsManagementApi.md#pull_payments_get_pull_payments) | **GET** /api/v1/stores/{storeId}/pull-payments | Get store&#x27;s pull payments
*PullPaymentsPublicApi* | [**pull_payments_create_payout**](docs/PullPaymentsPublicApi.md#pull_payments_create_payout) | **POST** /api/v1/pull-payments/{pullPaymentId}/payouts | Create Payout
*PullPaymentsPublicApi* | [**pull_payments_get_payout**](docs/PullPaymentsPublicApi.md#pull_payments_get_payout) | **GET** /api/v1/pull-payments/{pullPaymentId}/payouts/{payoutId} | Get Payout
*PullPaymentsPublicApi* | [**pull_payments_get_payouts**](docs/PullPaymentsPublicApi.md#pull_payments_get_payouts) | **GET** /api/v1/pull-payments/{pullPaymentId}/payouts | Get Payouts
*PullPaymentsPublicApi* | [**pull_payments_get_pull_payment**](docs/PullPaymentsPublicApi.md#pull_payments_get_pull_payment) | **GET** /api/v1/pull-payments/{pullPaymentId} | Get Pull Payment
*PullPaymentsPayoutPublicApi* | [**pull_payments_get_payout**](docs/PullPaymentsPayoutPublicApi.md#pull_payments_get_payout) | **GET** /api/v1/pull-payments/{pullPaymentId}/payouts/{payoutId} | Get Payout
*ServerInfoApi* | [**server_info_get_server_info**](docs/ServerInfoApi.md#server_info_get_server_info) | **GET** /api/v1/server/info | Get server info
*StorePaymentMethodsApi* | [**store_payment_methods_get_store_payment_methods**](docs/StorePaymentMethodsApi.md#store_payment_methods_get_store_payment_methods) | **GET** /api/v1/stores/{storeId}/payment-methods | Get store payment methods
*StorePaymentMethodsLNURLPayApi* | [**api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete**](docs/StorePaymentMethodsLNURLPayApi.md#api_v1_stores_store_id_payment_methods_lnurl_crypto_code_delete) | **DELETE** /api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode} | Remove store LNURL Pay payment method
*StorePaymentMethodsLNURLPayApi* | [**store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method**](docs/StorePaymentMethodsLNURLPayApi.md#store_lnurl_pay_payment_methods_get_lnurl_pay_payment_method) | **GET** /api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode} | Get store LNURL Pay payment method
*StorePaymentMethodsLNURLPayApi* | [**store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods**](docs/StorePaymentMethodsLNURLPayApi.md#store_lnurl_pay_payment_methods_get_lnurl_pay_payment_methods) | **GET** /api/v1/stores/{storeId}/payment-methods/LNURL | Get store LNURL payment methods
*StorePaymentMethodsLNURLPayApi* | [**store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method**](docs/StorePaymentMethodsLNURLPayApi.md#store_lnurl_pay_payment_methods_update_lnurl_pay_payment_method) | **PUT** /api/v1/stores/{storeId}/payment-methods/LNURL/{cryptoCode} | Update store LNURL Pay payment method
*StorePaymentMethodsLightningNetworkApi* | [**api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete**](docs/StorePaymentMethodsLightningNetworkApi.md#api_v1_stores_store_id_payment_methods_lightning_network_crypto_code_delete) | **DELETE** /api/v1/stores/{storeId}/payment-methods/LightningNetwork/{cryptoCode} | Remove store Lightning Network payment method
*StorePaymentMethodsLightningNetworkApi* | [**store_lightning_network_payment_methods_get_lightning_network_payment_method**](docs/StorePaymentMethodsLightningNetworkApi.md#store_lightning_network_payment_methods_get_lightning_network_payment_method) | **GET** /api/v1/stores/{storeId}/payment-methods/LightningNetwork/{cryptoCode} | Get store Lightning Network payment method
*StorePaymentMethodsLightningNetworkApi* | [**store_lightning_network_payment_methods_get_lightning_network_payment_methods**](docs/StorePaymentMethodsLightningNetworkApi.md#store_lightning_network_payment_methods_get_lightning_network_payment_methods) | **GET** /api/v1/stores/{storeId}/payment-methods/LightningNetwork | Get store Lightning Network payment methods
*StorePaymentMethodsLightningNetworkApi* | [**store_lightning_network_payment_methods_update_lightning_network_payment_method**](docs/StorePaymentMethodsLightningNetworkApi.md#store_lightning_network_payment_methods_update_lightning_network_payment_method) | **PUT** /api/v1/stores/{storeId}/payment-methods/LightningNetwork/{cryptoCode} | Update store Lightning Network payment method
*StorePaymentMethodsOnChainApi* | [**api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete**](docs/StorePaymentMethodsOnChainApi.md#api_v1_stores_store_id_payment_methods_onchain_crypto_code_delete) | **DELETE** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode} | Remove store on-chain payment method
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_generate_on_chain_wallet**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_generate_on_chain_wallet) | **POST** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/generate | Generate store on-chain wallet
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_get_on_chain_payment_method**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_get_on_chain_payment_method) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode} | Get store on-chain payment method
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_get_on_chain_payment_method_preview**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_get_on_chain_payment_method_preview) | **GET** /api/v1/stores/{storeId}/payment-methods/OnChain/{cryptoCode}/preview | Preview store on-chain payment method addresses
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_get_on_chain_payment_methods**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_get_on_chain_payment_methods) | **GET** /api/v1/stores/{storeId}/payment-methods/OnChain | Get store on-chain payment methods
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_post_on_chain_payment_method_preview**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_post_on_chain_payment_method_preview) | **POST** /api/v1/stores/{storeId}/payment-methods/OnChain/{cryptoCode}/preview | Preview proposed store on-chain payment method addresses
*StorePaymentMethodsOnChainApi* | [**store_on_chain_payment_methods_update_on_chain_payment_method**](docs/StorePaymentMethodsOnChainApi.md#store_on_chain_payment_methods_update_on_chain_payment_method) | **PUT** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode} | Update store on-chain payment method
*StoreWalletOnChainApi* | [**store_on_chain_wallets_create_on_chain_transaction**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_create_on_chain_transaction) | **POST** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions | Create store on-chain wallet transaction
*StoreWalletOnChainApi* | [**store_on_chain_wallets_get_on_chain_fee_rate**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_get_on_chain_fee_rate) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/feerate | Get store on-chain wallet fee rate
*StoreWalletOnChainApi* | [**store_on_chain_wallets_get_on_chain_wallet_receive_address**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_get_on_chain_wallet_receive_address) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/address | Get store on-chain wallet address
*StoreWalletOnChainApi* | [**store_on_chain_wallets_get_on_chain_wallet_transaction**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_get_on_chain_wallet_transaction) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions/{transactionId} | Get store on-chain wallet transaction
*StoreWalletOnChainApi* | [**store_on_chain_wallets_get_on_chain_wallet_utx_os**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_get_on_chain_wallet_utx_os) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/utxos | Get store on-chain wallet UTXOS
*StoreWalletOnChainApi* | [**store_on_chain_wallets_patch_on_chain_wallet_transaction**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_patch_on_chain_wallet_transaction) | **PATCH** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions/{transactionId} | Patch store on-chain wallet transaction info
*StoreWalletOnChainApi* | [**store_on_chain_wallets_show_on_chain_wallet_overview**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_show_on_chain_wallet_overview) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet | Get store on-chain wallet overview
*StoreWalletOnChainApi* | [**store_on_chain_wallets_show_on_chain_wallet_transactions**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_show_on_chain_wallet_transactions) | **GET** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/transactions | Get store on-chain wallet transactions
*StoreWalletOnChainApi* | [**store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address**](docs/StoreWalletOnChainApi.md#store_on_chain_wallets_un_reserve_on_chain_wallet_receive_address) | **DELETE** /api/v1/stores/{storeId}/payment-methods/onchain/{cryptoCode}/wallet/address | UnReserve last store on-chain wallet address
*StoresApi* | [**api_v1_stores_post**](docs/StoresApi.md#api_v1_stores_post) | **POST** /api/v1/stores | Create a new store
*StoresApi* | [**api_v1_stores_store_id_delete**](docs/StoresApi.md#api_v1_stores_store_id_delete) | **DELETE** /api/v1/stores/{storeId} | Remove Store
*StoresApi* | [**stores_get_store**](docs/StoresApi.md#stores_get_store) | **GET** /api/v1/stores/{storeId} | Get store
*StoresApi* | [**stores_get_stores**](docs/StoresApi.md#stores_get_stores) | **GET** /api/v1/stores | Get stores
*StoresApi* | [**stores_update_store**](docs/StoresApi.md#stores_update_store) | **PUT** /api/v1/stores/{storeId} | Update store
*StoresEmailApi* | [**api_v1_stores_store_id_email_send_post**](docs/StoresEmailApi.md#api_v1_stores_store_id_email_send_post) | **POST** /api/v1/stores/{storeId}/email/send | Send an email for a store
*StoresEmailApi* | [**stores_get_store_email_settings**](docs/StoresEmailApi.md#stores_get_store_email_settings) | **GET** /api/v1/stores/{storeId}/email | Get store email settings
*StoresEmailApi* | [**stores_update_store_email_settings**](docs/StoresEmailApi.md#stores_update_store_email_settings) | **PUT** /api/v1/stores/{storeId}/email | Update store email settings
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors) | **GET** /api/v1/stores/{storeId}/payout-processors/LightningAutomatedTransferSenderFactory/{paymentMethod} | Get configured store Lightning automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0) | **GET** /api/v1/stores/{storeId}/payout-processors/LightningAutomatedTransferSenderFactory | Get configured store Lightning automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor) | **PUT** /api/v1/stores/{storeId}/payout-processors/LightningAutomatedTransferSenderFactory/{paymentMethod} | Update configured store Lightning automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors) | **GET** /api/v1/stores/{storeId}/payout-processors/OnChainAutomatedTransferSenderFactory/{paymentMethod} | Get configured store onchain automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0) | **GET** /api/v1/stores/{storeId}/payout-processors/OnChainAutomatedTransferSenderFactory | Get configured store onchain automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor) | **PUT** /api/v1/stores/{storeId}/payout-processors/OnChainAutomatedTransferSenderFactory/{paymentMethod} | Update configured store onchain automated payout processors
*StoresPayoutProcessorsApi* | [**greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0**](docs/StoresPayoutProcessorsApi.md#greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0) | **PUT** /api/v1/stores/{storeId}/payout-processors/OnChainAutomatedTransferSenderFactory | Update configured store onchain automated payout processors
*StoresPayoutProcessorsApi* | [**store_payout_processors_get_store_payout_processors**](docs/StoresPayoutProcessorsApi.md#store_payout_processors_get_store_payout_processors) | **GET** /api/v1/stores/{storeId}/payout-processors | Get store configured payout processors
*StoresPayoutProcessorsApi* | [**store_payout_processors_remove_store_payout_processor**](docs/StoresPayoutProcessorsApi.md#store_payout_processors_remove_store_payout_processor) | **DELETE** /api/v1/stores/{storeId}/payout-processors/{processor}/{paymentMethod} | Remove store configured payout processor
*StoresPayoutsApi* | [**payouts_create_payout_through_store**](docs/StoresPayoutsApi.md#payouts_create_payout_through_store) | **POST** /api/v1/stores/{storeId}/payouts | Create Payout 
*StoresPayoutsApi* | [**pull_payments_approve_payout**](docs/StoresPayoutsApi.md#pull_payments_approve_payout) | **POST** /api/v1/stores/{storeId}/payouts/{payoutId} | Approve Payout
*StoresPayoutsApi* | [**pull_payments_cancel_payout**](docs/StoresPayoutsApi.md#pull_payments_cancel_payout) | **DELETE** /api/v1/stores/{storeId}/payouts/{payoutId} | Cancel Payout
*StoresPayoutsApi* | [**pull_payments_get_store_payouts**](docs/StoresPayoutsApi.md#pull_payments_get_store_payouts) | **GET** /api/v1/stores/{storeId}/payouts | Get Store Payouts
*StoresPayoutsApi* | [**pull_payments_mark_payout_paid**](docs/StoresPayoutsApi.md#pull_payments_mark_payout_paid) | **POST** /api/v1/stores/{storeId}/payouts/{payoutId}/mark-paid | Mark Payout as Paid
*StoresUsersApi* | [**stores_add_store_user**](docs/StoresUsersApi.md#stores_add_store_user) | **POST** /api/v1/stores/{storeId}/users | Add a store user
*StoresUsersApi* | [**stores_get_store_users**](docs/StoresUsersApi.md#stores_get_store_users) | **GET** /api/v1/stores/{storeId}/users | Get store users
*StoresUsersApi* | [**stores_remove_store_user**](docs/StoresUsersApi.md#stores_remove_store_user) | **DELETE** /api/v1/stores/{storeId}/users/{userId} | Remove Store User
*UsersApi* | [**api_v1_users_get**](docs/UsersApi.md#api_v1_users_get) | **GET** /api/v1/users | Get all users
*UsersApi* | [**api_v1_users_id_or_email_delete**](docs/UsersApi.md#api_v1_users_id_or_email_delete) | **DELETE** /api/v1/users/{idOrEmail} | Delete user
*UsersApi* | [**api_v1_users_id_or_email_get**](docs/UsersApi.md#api_v1_users_id_or_email_get) | **GET** /api/v1/users/{idOrEmail} | Get user by ID or Email
*UsersApi* | [**api_v1_users_id_or_email_lock_delete**](docs/UsersApi.md#api_v1_users_id_or_email_lock_delete) | **DELETE** /api/v1/users/{idOrEmail}/lock | Toggle user
*UsersApi* | [**api_v1_users_post**](docs/UsersApi.md#api_v1_users_post) | **POST** /api/v1/users | Create user
*UsersApi* | [**users_delete_current_user**](docs/UsersApi.md#users_delete_current_user) | **DELETE** /api/v1/users/me | Deletes user profile
*UsersApi* | [**users_get_current_user**](docs/UsersApi.md#users_get_current_user) | **GET** /api/v1/users/me | Get current user information
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_post**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_post) | **POST** /api/v1/stores/{storeId}/webhooks | Create a new webhook
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_delete**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_delete) | **DELETE** /api/v1/stores/{storeId}/webhooks/{webhookId} | Delete a webhook
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get) | **GET** /api/v1/stores/{storeId}/webhooks/{webhookId}/deliveries/{deliveryId} | Get a webhook delivery
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post) | **POST** /api/v1/stores/{storeId}/webhooks/{webhookId}/deliveries/{deliveryId}/redeliver | Redeliver the delivery
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get) | **GET** /api/v1/stores/{storeId}/webhooks/{webhookId}/deliveries/{deliveryId}/request | Get the delivery&#x27;s request
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_deliveries_get**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_deliveries_get) | **GET** /api/v1/stores/{storeId}/webhooks/{webhookId}/deliveries | Get latest deliveries
*WebhooksApi* | [**api_v1_stores_store_id_webhooks_webhook_id_put**](docs/WebhooksApi.md#api_v1_stores_store_id_webhooks_webhook_id_put) | **PUT** /api/v1/stores/{storeId}/webhooks/{webhookId} | Update a webhook
*WebhooksApi* | [**webhokks_get_webhook**](docs/WebhooksApi.md#webhokks_get_webhook) | **GET** /api/v1/stores/{storeId}/webhooks/{webhookId} | Get a webhook of a store
*WebhooksApi* | [**webhokks_get_webhooks**](docs/WebhooksApi.md#webhokks_get_webhooks) | **GET** /api/v1/stores/{storeId}/webhooks | Get webhooks of a store

## Documentation For Models

 - [AddCustomerEmailRequest](docs/AddCustomerEmailRequest.md)
 - [AllOfApplicationUserDataCreated](docs/AllOfApplicationUserDataCreated.md)
 - [AllOfCheckoutOptionsExpirationMinutes](docs/AllOfCheckoutOptionsExpirationMinutes.md)
 - [AllOfCheckoutOptionsMonitoringMinutes](docs/AllOfCheckoutOptionsMonitoringMinutes.md)
 - [AllOfCreateLightningInvoiceRequestExpiry](docs/AllOfCreateLightningInvoiceRequestExpiry.md)
 - [AllOfLightningAutomatedTransferSettingsIntervalSeconds](docs/AllOfLightningAutomatedTransferSettingsIntervalSeconds.md)
 - [AllOfLightningInvoiceDataExpiresAt](docs/AllOfLightningInvoiceDataExpiresAt.md)
 - [AllOfLightningInvoiceDataPaidAt](docs/AllOfLightningInvoiceDataPaidAt.md)
 - [AllOfLightningPaymentDataCreatedAt](docs/AllOfLightningPaymentDataCreatedAt.md)
 - [AllOfNotificationDataCreatedTime](docs/AllOfNotificationDataCreatedTime.md)
 - [AllOfOnChainAutomatedTransferSettingsIntervalSeconds](docs/AllOfOnChainAutomatedTransferSettingsIntervalSeconds.md)
 - [AllOfOnChainWalletTransactionDataTimestamp](docs/AllOfOnChainWalletTransactionDataTimestamp.md)
 - [AllOfOnChainWalletUTXODataTimestamp](docs/AllOfOnChainWalletUTXODataTimestamp.md)
 - [AllOfPaymentReceivedDate](docs/AllOfPaymentReceivedDate.md)
 - [AllOfPaymentRequestBaseDataExpiryDate](docs/AllOfPaymentRequestBaseDataExpiryDate.md)
 - [AllOfStoreBaseDataInvoiceExpiration](docs/AllOfStoreBaseDataInvoiceExpiration.md)
 - [AllOfStoreBaseDataMonitoringExpiration](docs/AllOfStoreBaseDataMonitoringExpiration.md)
 - [AllOfUpdateLightningAutomatedTransferSettingsIntervalSeconds](docs/AllOfUpdateLightningAutomatedTransferSettingsIntervalSeconds.md)
 - [AllOfUpdateOnChainAutomatedTransferSettingsIntervalSeconds](docs/AllOfUpdateOnChainAutomatedTransferSettingsIntervalSeconds.md)
 - [AllOfWebhookDeliveryDataTimestamp](docs/AllOfWebhookDeliveryDataTimestamp.md)
 - [AllOfWebhookEventTimestamp](docs/AllOfWebhookEventTimestamp.md)
 - [AnyOfInvoiceMetadata](docs/AnyOfInvoiceMetadata.md)
 - [AnyOfInvoicePaymentMethodDataModelAdditionalData](docs/AnyOfInvoicePaymentMethodDataModelAdditionalData.md)
 - [ApiKeyData](docs/ApiKeyData.md)
 - [ApplicationHealthData](docs/ApplicationHealthData.md)
 - [ApplicationServerInfoData](docs/ApplicationServerInfoData.md)
 - [ApplicationServerInfoNodeStatusData](docs/ApplicationServerInfoNodeStatusData.md)
 - [ApplicationServerInfoSyncStatusData](docs/ApplicationServerInfoSyncStatusData.md)
 - [ApplicationUserData](docs/ApplicationUserData.md)
 - [AppsPosBody](docs/AppsPosBody.md)
 - [AssetBalanceData](docs/AssetBalanceData.md)
 - [BasicAppData](docs/BasicAppData.md)
 - [CheckoutOptions](docs/CheckoutOptions.md)
 - [ConnectToNodeRequest](docs/ConnectToNodeRequest.md)
 - [CreateCustodianAccountRequest](docs/CreateCustodianAccountRequest.md)
 - [CreateInvoiceRequest](docs/CreateInvoiceRequest.md)
 - [CreateLightningInvoiceRequest](docs/CreateLightningInvoiceRequest.md)
 - [CreateOnChainTransactionRequest](docs/CreateOnChainTransactionRequest.md)
 - [CreateOnChainTransactionRequestDestination](docs/CreateOnChainTransactionRequestDestination.md)
 - [CreatePayoutRequest](docs/CreatePayoutRequest.md)
 - [CreatePayoutThroughStoreRequest](docs/CreatePayoutThroughStoreRequest.md)
 - [CryptoCodePreviewBody](docs/CryptoCodePreviewBody.md)
 - [CustodianAccountData](docs/CustodianAccountData.md)
 - [CustodianData](docs/CustodianData.md)
 - [EmailData](docs/EmailData.md)
 - [EmailSettingsData](docs/EmailSettingsData.md)
 - [GenerateOnChainWalletRequest](docs/GenerateOnChainWalletRequest.md)
 - [GenericPaymentMethodData](docs/GenericPaymentMethodData.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse403](docs/InlineResponse403.md)
 - [InvoiceAdditionalStatus](docs/InvoiceAdditionalStatus.md)
 - [InvoiceData](docs/InvoiceData.md)
 - [InvoiceDataBase](docs/InvoiceDataBase.md)
 - [InvoiceDataList](docs/InvoiceDataList.md)
 - [InvoiceMetadata](docs/InvoiceMetadata.md)
 - [InvoiceMetadataPosObject](docs/InvoiceMetadataPosObject.md)
 - [InvoiceMetadataPosString](docs/InvoiceMetadataPosString.md)
 - [InvoicePaymentMethodDataModel](docs/InvoicePaymentMethodDataModel.md)
 - [InvoiceStatus](docs/InvoiceStatus.md)
 - [InvoiceStatusMark](docs/InvoiceStatusMark.md)
 - [InvoiceType](docs/InvoiceType.md)
 - [LNURLPayPaymentMethodBaseData](docs/LNURLPayPaymentMethodBaseData.md)
 - [LNURLPayPaymentMethodData](docs/LNURLPayPaymentMethodData.md)
 - [LNURLPayPaymentMethodDataList](docs/LNURLPayPaymentMethodDataList.md)
 - [LabelData](docs/LabelData.md)
 - [LedgerEntryData](docs/LedgerEntryData.md)
 - [LedgerEntryType](docs/LedgerEntryType.md)
 - [LightningAutomatedTransferSettings](docs/LightningAutomatedTransferSettings.md)
 - [LightningChannelData](docs/LightningChannelData.md)
 - [LightningInvoiceData](docs/LightningInvoiceData.md)
 - [LightningInvoiceStatus](docs/LightningInvoiceStatus.md)
 - [LightningNetworkPaymentMethodBaseData](docs/LightningNetworkPaymentMethodBaseData.md)
 - [LightningNetworkPaymentMethodData](docs/LightningNetworkPaymentMethodData.md)
 - [LightningNetworkPaymentMethodDataList](docs/LightningNetworkPaymentMethodDataList.md)
 - [LightningNodeBalanceData](docs/LightningNodeBalanceData.md)
 - [LightningNodeInformationData](docs/LightningNodeInformationData.md)
 - [LightningPaymentData](docs/LightningPaymentData.md)
 - [LightningPaymentStatus](docs/LightningPaymentStatus.md)
 - [LockUserRequest](docs/LockUserRequest.md)
 - [MarkInvoiceStatusRequest](docs/MarkInvoiceStatusRequest.md)
 - [NetworkFeeMode](docs/NetworkFeeMode.md)
 - [NotificationData](docs/NotificationData.md)
 - [OffchainBalanceData](docs/OffchainBalanceData.md)
 - [OnChainAutomatedTransferSettings](docs/OnChainAutomatedTransferSettings.md)
 - [OnChainPaymentMethodBaseData](docs/OnChainPaymentMethodBaseData.md)
 - [OnChainPaymentMethodData](docs/OnChainPaymentMethodData.md)
 - [OnChainPaymentMethodDataList](docs/OnChainPaymentMethodDataList.md)
 - [OnChainPaymentMethodDataPreview](docs/OnChainPaymentMethodDataPreview.md)
 - [OnChainPaymentMethodDataWithSensitiveData](docs/OnChainPaymentMethodDataWithSensitiveData.md)
 - [OnChainPaymentMethodPreviewResultAddressItem](docs/OnChainPaymentMethodPreviewResultAddressItem.md)
 - [OnChainPaymentMethodPreviewResultData](docs/OnChainPaymentMethodPreviewResultData.md)
 - [OnChainWalletAddressData](docs/OnChainWalletAddressData.md)
 - [OnChainWalletFeeRateData](docs/OnChainWalletFeeRateData.md)
 - [OnChainWalletOverviewData](docs/OnChainWalletOverviewData.md)
 - [OnChainWalletTransactionData](docs/OnChainWalletTransactionData.md)
 - [OnChainWalletUTXOData](docs/OnChainWalletUTXOData.md)
 - [OnchainBalanceData](docs/OnchainBalanceData.md)
 - [OneOfGenericPaymentMethodDataData](docs/OneOfGenericPaymentMethodDataData.md)
 - [OneOfTradeRequestDataQty](docs/OneOfTradeRequestDataQty.md)
 - [OneOfinlineResponse2003](docs/OneOfinlineResponse2003.md)
 - [OneOfinlineResponse403](docs/OneOfinlineResponse403.md)
 - [OpenLightningChannelRequest](docs/OpenLightningChannelRequest.md)
 - [PatchOnChainTransactionRequest](docs/PatchOnChainTransactionRequest.md)
 - [PayLightningInvoiceRequest](docs/PayLightningInvoiceRequest.md)
 - [Payment](docs/Payment.md)
 - [PaymentRequestBaseData](docs/PaymentRequestBaseData.md)
 - [PaymentRequestData](docs/PaymentRequestData.md)
 - [PaymentRequestDataList](docs/PaymentRequestDataList.md)
 - [PaymentStatus](docs/PaymentStatus.md)
 - [PayoutData](docs/PayoutData.md)
 - [PayoutDataList](docs/PayoutDataList.md)
 - [PayoutProcessorData](docs/PayoutProcessorData.md)
 - [PayoutsPayoutIdBody](docs/PayoutsPayoutIdBody.md)
 - [PointOfSaleAppData](docs/PointOfSaleAppData.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [PullPaymentData](docs/PullPaymentData.md)
 - [PullPaymentDataList](docs/PullPaymentDataList.md)
 - [QuoteResultData](docs/QuoteResultData.md)
 - [ReceiptOptions](docs/ReceiptOptions.md)
 - [SpeedPolicy](docs/SpeedPolicy.md)
 - [StoreBaseData](docs/StoreBaseData.md)
 - [StoreData](docs/StoreData.md)
 - [StoreDataList](docs/StoreDataList.md)
 - [StoreIdPullpaymentsBody](docs/StoreIdPullpaymentsBody.md)
 - [StoreUserData](docs/StoreUserData.md)
 - [StoreUserDataList](docs/StoreUserDataList.md)
 - [TimeSpan](docs/TimeSpan.md)
 - [TimeSpanMinutes](docs/TimeSpanMinutes.md)
 - [TimeSpanSeconds](docs/TimeSpanSeconds.md)
 - [TradeRequestData](docs/TradeRequestData.md)
 - [TradeResultData](docs/TradeResultData.md)
 - [TransactionStatus](docs/TransactionStatus.md)
 - [UnixTimestamp](docs/UnixTimestamp.md)
 - [UpdateInvoiceRequest](docs/UpdateInvoiceRequest.md)
 - [UpdateLightningAutomatedTransferSettings](docs/UpdateLightningAutomatedTransferSettings.md)
 - [UpdateLightningNetworkPaymentMethodRequest](docs/UpdateLightningNetworkPaymentMethodRequest.md)
 - [UpdateNotification](docs/UpdateNotification.md)
 - [UpdateOnChainAutomatedTransferSettings](docs/UpdateOnChainAutomatedTransferSettings.md)
 - [UpdateOnChainPaymentMethodRequest](docs/UpdateOnChainPaymentMethodRequest.md)
 - [V1ApikeysBody](docs/V1ApikeysBody.md)
 - [V1UsersBody](docs/V1UsersBody.md)
 - [ValidationProblemDetails](docs/ValidationProblemDetails.md)
 - [ValidationProblemDetailsInner](docs/ValidationProblemDetailsInner.md)
 - [WebhookData](docs/WebhookData.md)
 - [WebhookDataBase](docs/WebhookDataBase.md)
 - [WebhookDataBaseAuthorizedEvents](docs/WebhookDataBaseAuthorizedEvents.md)
 - [WebhookDataCreate](docs/WebhookDataCreate.md)
 - [WebhookDataList](docs/WebhookDataList.md)
 - [WebhookDeliveryData](docs/WebhookDeliveryData.md)
 - [WebhookDeliveryList](docs/WebhookDeliveryList.md)
 - [WebhookEvent](docs/WebhookEvent.md)
 - [WebhookInvoiceEvent](docs/WebhookInvoiceEvent.md)
 - [WebhookInvoiceExpiredEvent](docs/WebhookInvoiceExpiredEvent.md)
 - [WebhookInvoiceInvalidEvent](docs/WebhookInvoiceInvalidEvent.md)
 - [WebhookInvoicePaymentSettledEvent](docs/WebhookInvoicePaymentSettledEvent.md)
 - [WebhookInvoiceProcessingEvent](docs/WebhookInvoiceProcessingEvent.md)
 - [WebhookInvoiceReceivedPaymentEvent](docs/WebhookInvoiceReceivedPaymentEvent.md)
 - [WebhookInvoiceSettledEvent](docs/WebhookInvoiceSettledEvent.md)
 - [WithdrawalRequestData](docs/WithdrawalRequestData.md)
 - [WithdrawalResultData](docs/WithdrawalResultData.md)

## Documentation For Authorization


## API_Key

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

## Basic

- **Type**: HTTP basic authentication


## Author


